package net.wanji.common.enums;
import java.util.*;

public class StrategyAndMetricsEnum {

    public enum Strategy {
        BALANCE("100030", "均衡调控"),
        EFFICIENCY("100152", "效率提升"),
        SECURITY("100010", "安全保障");

        private final String code;
        private final String msg;

        Strategy(String code, String msg) {
            this.code = code;
            this.msg = msg;
        }

        public static String getMsgByCode(String code) {
            for (Strategy value : Strategy.values()) {
                if (value.code.equals(code)) {
                    return value.msg;
                }
            }
            return null;
        }

        public String getMsg() {
            return msg;
        }

        public String getCode() {
            return code;
        }
    }

    public enum Metrics {
        NO_STOP_THROUGH_RATE(1, "不停车通过率", "%"),
        STOP_THROUGH_RATE(2, "一/二/三次及以上停车通过率", "%"),
        AVERAGE_DELAY(3, "平均延误", "s"),
        MAX_QUEUE_LENGTH(4, "最大排队长度", "m"),
        STOP_COUNT(5, "停车次数", "次"),
        AVERAGE_SPEED(6, "平均速度", "km/h"),
        GREEN_LIGHT_UTILIZATION(7, "绿灯有效利用率", "%"),
        SATURATION(8, "饱和度", ""),
        LOAD_BALANCE(9, "负载均衡度", ""),
        OVERFLOW_RATE(10, "溢流率", "%"),
        GREEN_INTERVAL_CLEAR(11, "绿灯间隔清空率", "%"),
        EMERGENCY_COUNT(12, "三急一速数量", "");

        private final Integer code;
        private final String description;
        private final String unit;


        Metrics(Integer code, String description, String unit) {
            this.code = code;
            this.description = description;
            this.unit = unit;
        }

        public String getDescription() {
            return description;
        }

        public Integer getCode() {
            return code;
        }

        public String getUnit() {
            return unit;
        }
    }

    public static final Map<Strategy, List<Metrics>> STRATEGY_METRICS_MAP;

    static {
        Map<Strategy, List<Metrics>> map = new HashMap<>();
        map.put(Strategy.EFFICIENCY, Arrays.asList(
                Metrics.NO_STOP_THROUGH_RATE,
                Metrics.STOP_THROUGH_RATE,
                Metrics.AVERAGE_DELAY,
                Metrics.MAX_QUEUE_LENGTH,
                Metrics.STOP_COUNT,
                Metrics.AVERAGE_SPEED
        ));
        map.put(Strategy.BALANCE, Arrays.asList(
                Metrics.GREEN_LIGHT_UTILIZATION,
                Metrics.SATURATION,
                Metrics.LOAD_BALANCE
        ));
        map.put(Strategy.SECURITY, Arrays.asList(
                Metrics.OVERFLOW_RATE,
                Metrics.GREEN_INTERVAL_CLEAR,
                Metrics.EMERGENCY_COUNT
        ));
        STRATEGY_METRICS_MAP = Collections.unmodifiableMap(map);
    }

    public static void main(String[] args) {
        // 示例：获取"效率提升"策略的所有指标
        List<Metrics> efficiencyMetrics = STRATEGY_METRICS_MAP.get(Strategy.EFFICIENCY);
        System.out.println("效率提升的指标有：");
        for (Metrics metric : efficiencyMetrics) {
            System.out.println(metric.getDescription());
        }
    }
}
